@@ -274,7 +274,8 @@ class Alerter(object):
     def send(self, event, message):
         if self.settings is None or self.settings.recipientAddress is None:
             return
-        if not getattr(self.settings, 'alertOn%s' % (event,)):
+        alertSetting = getattr(self.settings, 'alertOn%s' % (event,))
+        if not alertSetting:
             return
 
         from twisted.mail.smtp import sendmail
@@ -282,7 +283,10 @@ class Alerter(object):
         msg = MIMEText(message)
         msg['Subject'] = self.settings.subject
         msg['From'] = sender = self.settings.senderAddress
-        msg['To'] = recipient = self.settings.recipientAddress
+        if isinstance(alertSetting, (str, unicode)):
+            msg['To'] = recipient = alertSetting
+        else:
+            msg['To'] = recipient = self.settings.recipientAddress
 
         sendmail(self.settings.smtpServer, sender, [recipient], msg.as_string())
 
