@@ -341,11 +341,9 @@ class ChecklistAchievement(Achievement):
         super(ChecklistAchievement, self).__init__(player, world, outPlug)
 
     def addItem(self, item):
-        if item not in self.requiredItems:
-            return
         self.progress.add(item)
 
-        if len(self.requiredItems - self.progress) == 0:
+        if self.requiredItems == self.progress:
             self.achievementUnlocked()
 
     def __str__(self):
@@ -373,7 +371,7 @@ class PersistedChecklistAchievement(ChecklistAchievement, OnceEverPerPlayer):
 
     def getJsonString(self):
         return {
-            'unlocked' : self.unlocked,
+            'unlocked' : self.unlocked or self.previouslyUnlocked,
             # JSON doesn't support sets:
             'progress' : list(self.progress),
         }
@@ -1058,7 +1056,8 @@ class KillEveryLeader(KilledSomeoneAchievement, PersistedChecklistAchievement):
         if player.user is None:
             return
         nick = stripPunctuation(player.user.username).lower()
-        self.addItem(nick)
+        if nick in self.requiredItems:
+            self.addItem(nick)
 
 concreteAchievements = (MultiTagSmall, MultiTagMedium, MultiTagLarge,
     TotalTagsSmall, TotalTagsMedium, MultiKillSmall, MultiKillMedium,
