@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -45,7 +45,7 @@ class ScaledScalar(object):
         self.val = val
         self._val = None
         self._scaleFactor = None
-        
+
     def getVal(self, app):
         sf = app.screenManager.scaleFactor
         if self._scaleFactor != sf:
@@ -80,7 +80,7 @@ class ScaledScreenAttachedPoint(object):
         else:
             val = self.val
         pos = getattr(app.screenManager.scaledRect, self.attachedAt)
-        return addPositions(pos, val)    
+        return addPositions(pos, val)
 
 class AttachedPoint(object):
     '''
@@ -144,7 +144,8 @@ class SizedImage(NewImage):
         self.size = size
 
     def getImage(self, app):
-        if self.sizedImage is not None and self.lastSize == self._getCurrentSize(app):
+        if (self.sizedImage is not None and self.lastSize ==
+                self._getCurrentSize(app)):
             return self.sizedImage
         img = super(SizedImage, self).getImage(app)
         self.lastSize = self._getCurrentSize(app)
@@ -160,8 +161,9 @@ class SizedImage(NewImage):
 
 class TextImage(NewImage):
     '''Shows text at a specified screen location.'''
-    
-    def __init__(self, text, font, colour=(0,128,0), bgColour=None, antialias=True):
+
+    def __init__(self, text, font, colour=(0,128,0), bgColour=None,
+            antialias=True):
         self.colour = colour
         self.bgColour = bgColour
         self._text = str(text)
@@ -175,8 +177,9 @@ class TextImage(NewImage):
     text = property(getText, setText)
 
     def getImage(self, app):
-        return self.font.render(app, self._text, self.antialias, self.colour, self.bgColour)
- 
+        return self.font.render(app, self._text, self.antialias, self.colour,
+                self.bgColour)
+
 
 class Location(object):
     '''
@@ -184,7 +187,7 @@ class Location(object):
     @param  anchor  a string representing the rectangle attribute which this
                     location will reposition
     '''
-    def __init__(self, point, anchor=defaultAnchor):            
+    def __init__(self, point, anchor=defaultAnchor):
         if anchor == 'centre':
             anchor = 'center'
         self.point = point
@@ -207,8 +210,9 @@ class RelativeLocation(Location):
         self.location = location
 
     def __repr__(self):
-        return 'RelativeLocation: (%s plus %s)' % (repr(self.location), repr(self.size))
-        
+        return 'RelativeLocation: (%s plus %s)' % (repr(self.location),
+                repr(self.size))
+
     def apply(self, app, rect):
         self.location.apply(app, rect)
         if hasattr(self.size, 'getSize'):
@@ -242,7 +246,8 @@ class Area(Location):
         return result
 
     def __repr__(self):
-        return "Area: point is %s, size is %s, anchored at %s" % (repr(self.point), repr(self.size), self.anchor)
+        return "Area: point is %s, size is %s, anchored at %s" % (
+                repr(self.point), repr(self.size), self.anchor)
 
 
 class PygameEvent(object):
@@ -267,7 +272,7 @@ def translateEvent(event, amount):
             setattr(result, name, v)
     return result
 
-# For ease of use    
+# For ease of use
 def ScaledLocation(x, y, anchor = defaultAnchor):
     return Location(ScaledPoint(x, y), anchor)
 
@@ -409,7 +414,7 @@ class Region(object):
             if arg not in self.VALID_ARGS:
                 raise TypeError('Region() got an unexpected keyword argument '
                         + repr(arg))
-                
+
     def getRect(self, app):
         vals = self._evaluateConstraints(app)
         r = pygame.Rect((0, 0), (0, 0))
@@ -444,7 +449,7 @@ class Region(object):
     def _makeXConstraint(self, xConstraints):
         self._xInterval, args = self._getIntervalFunction(xConstraints)
         return self._standardXConstraint, args
-        
+
     def _makeYConstraint(self, yConstraints):
         self._yInterval, args = self._getIntervalFunction(yConstraints)
         return self._standardYConstraint, args
@@ -546,7 +551,7 @@ class Abs(object):
     def getRect(self, app):
         assert len(self.values) == 4
         return pygame.Rect(*self.values)
-        
+
 class Canvas(object):
     def __init__(self, *args):
         self.values = args
