@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,8 +15,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import logging
+
 import pygame
 
+log = logging.getLogger('fontcache')
+
 _cache = {}
 
 def get(filename, size):
@@ -26,7 +30,7 @@ def get(filename, size):
         try:
             result = pygame.font.Font(filename, size)
         except IOError:
-            print 'Font Cache: unable to load font %r' % (filename,)
+            log.error('Font Cache: unable to load font %r' % (filename,))
             result = pygame.font.Font(None, size)
 
         _cache[filename, size] = result
