@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,20 +18,27 @@
 '''mapLayout.py - takes care of initialising map blocks with obstacles and
  images.'''
 
+import logging
 import os, random
 from StringIO import StringIO
 
+import pygame
+
 from trosnoth.utils.utils import hasher
-from trosnoth.utils import logging, unrepr
+from trosnoth.utils import unrepr
 from trosnoth.model.map import MapLayout
 
 from trosnoth.data import getPath, user, makeDirs
 import trosnoth.data.blocks
 
-blockFiles = {'ForwardInterfaceMapBlock': 'fwd',
-              'BackwardInterfaceMapBlock': 'bck',
-              'TopBodyMapBlock': 'top',
-              'BottomBodyMapBlock': 'btm'}
+log = logging.getLogger('mapLayout')
+
+BLOCK_FILES = {
+    'ForwardInterfaceMapBlock': 'fwd',
+    'BackwardInterfaceMapBlock': 'bck',
+    'TopBodyMapBlock': 'top',
+    'BottomBodyMapBlock': 'btm',
+}
 
 class ChecksumError(Exception):
     pass
@@ -331,11 +338,8 @@ class LayoutDatastore(object):
         try:
             contentDict = unrepr.unrepr(contents)
             self.addLayout(filepath, **contentDict)
-        except:
-            print "Warning:"
-            logging.writeException()
-            print
-            print
+        except Exception, e:
+            log.warning(str(e))
             return False
         return True
 
@@ -360,7 +364,7 @@ class LayoutDatastore(object):
             graphicsIO = StringIO()
             graphicsIO.write(graphics.decode('base64'))
 
-        blockType = blockFiles[blockType]
+        blockType = BLOCK_FILES[blockType]
 
         newLayout = BlockLayout()
         newLayout.setProperties(graphicPath, obstacles, platforms,
@@ -427,9 +431,8 @@ class BlockLayout(object):
         '''
         return (self.kind, self.checksum, self.reversed)
 
-    def setProperties(self, graphicPath, obstacles, platforms, symmetrical, \
-                      checksum, blockType, filename, graphicsFilename,
-                      graphicsIO):
+    def setProperties(self, graphicPath, obstacles, platforms, symmetrical,
+            checksum, blockType, filename, graphicsFilename, graphicsIO):
         '''(graphicPath, obstacles, symmetrical) - sets the properties of
         this block layout.
 
@@ -457,7 +460,8 @@ class BlockLayout(object):
             if graphicPath:
                 # Check that the graphic exists.
                 if not os.path.exists(graphicPath):
-                    raise IOError, 'Graphic file does not exist: %s' % graphicPath
+                    raise IOError('Graphic file does not exist: %s' %
+                            graphicPath)
             self.graphics = FileBlockGraphics(graphicPath)
         else:
             self.graphics = StreamBlockGraphics(graphicsIO)
@@ -535,14 +539,11 @@ class BaseBlockGraphics(object):
         try:
             result = self._miniGraphics[scale]
         except KeyError:
-            width = self.graphic.get_rect().width / scale
-            height = self.graphic.get_rect().height / scale
+            width = int(self.graphic.get_rect().width / scale + 0.5)
+            height = int(self.graphic.get_rect().height / scale + 0.5)
 
-            # TODO: Perhaps put some time-limit on this cache in case
-            # someone asks for many many different scales.
-
-            import pygame
-            result = pygame.transform.smoothscale(self._rawGraphic, (width, height))
+            result = pygame.transform.smoothscale(self._rawGraphic, (width,
+                    height))
             self._miniGraphics[scale] = result
 
         return result
@@ -552,18 +553,16 @@ class BaseBlockGraphics(object):
             return self._graphic
 
         # Load the graphic.
-        import pygame
-
         self._rawGraphic = pygame.image.load(self._getFile(), 'png')
 
         if self._reversed:
             # Flip the graphic.
-            self._rawGraphic = \
-                    pygame.transform.flip(self._rawGraphic, True, False)
+            self._rawGraphic = pygame.transform.flip(self._rawGraphic, True,
+                    False)
 
         self._graphic = self._rawGraphic.convert()
         self._graphic.set_colorkey((255, 255, 255))
-        
+
         return self._graphic
 
     graphic = property(_getGraphic)
