@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,23 +15,26 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import logging
 from math import sin, cos
 import struct
 
-import trosnoth.utils.logging as logging
 from trosnoth.utils.checkpoint import checkpoint
 
 from trosnoth.model.unit import Unit
 from trosnoth.model.universe_base import GameState
 from trosnoth.model.map import MapLayout
+from trosnoth.utils.math import distance
 
 from trosnoth.messages import (DeleteUpgradeMsg, PlayerUpdateMsg,
         SetPlayerTeamMsg, PlayerKilledMsg, PlayerHitMsg, ShotAbsorbedMsg)
-from trosnoth.network.utils import compress_boolean
+from trosnoth.utils.network import compress_boolean
 
 RESPAWN_CAMP_TIME = 1.0
 MAX_STARS = 10
 
+log = logging.getLogger('player')
+
 class Player(Unit):
     '''Maintains the state of a player. This could be the user's player, a
     player on the network, or conceivably even a bot.
@@ -71,6 +74,7 @@ class Player(Unit):
         self.ghostThrust = 1.0      # Determined by mouse position
         self._faceRight = True
         self.reloadTime = 0.0
+        self.reloadFrom = 0.0
         self.turretHeat = 0.0
         self.respawnGauge = 0.0
         self.upgradeGauge = 0.0
@@ -81,6 +85,8 @@ class Player(Unit):
         self.upgrade = None
         self.turretOverHeated = False
         self.invulnerableUntil = None
+        self.mgBulletsRemaining = 0
+        self.mgFiring = False
 
         # Shots this player has fired
         self.shots = {}
@@ -114,7 +120,7 @@ class Player(Unit):
 
     @property
     def shielded(self):
-        return self.upgrade is not None and self.upgrade.upgradeType == 's'
+        return self.upgrade is not None and self.upgrade.upgradeType in 'sd'
 
     @property
     def phaseshift(self):
@@ -124,9 +130,36 @@ class Player(Unit):
     def turret(self):
         return self.upgrade is not None and self.upgrade.upgradeType == 't'
 
+    @property
+    def shoxwave(self):
+        return self.upgrade is not None and self.upgrade.upgradeType == 'w'
+
+    @property
+    def machineGunner(self):
+        return self.upgrade is not None and self.upgrade.upgradeType in 'xd'
+
     @property
     def hasRicochet(self):
-        return self.upgrade is not None and self.upgrade.upgradeType == 'r'
+        return self.upgrade is not None and self.upgrade.upgradeType in 'rd'
+
+    @property
+    def ninja(self):
+        return self.upgrade is not None and self.upgrade.upgradeType in 'nd'
+
+    @property
+    def disruptive(self):
+        return self.upgrade is not None and self.upgrade.upgradeType == 'm'
+
+    @property
+    def invisible (self):
+        return self.ninja and self.reloadTime == 0.0 and (
+                self.distanceFromCenter() > 200 or
+                self.isFriendsWithTeam(self.currentZone.orbOwner))
+
+    def distanceFromCenter(self):
+        zone = self.currentZone
+        distanceFromOrb = distance(zone.defn.pos, self.pos)
+        return distanceFromOrb
 
     def isAttachedToWall(self):
         '''
@@ -222,6 +255,18 @@ class Player(Unit):
                 return True
         return False
 
+    @staticmethod
+    def _leftValidator(obs):
+        return obs.deltaPt[0] == 0 and obs.deltaPt[1] > 0
+
+    @staticmethod
+    def _rightValidator(obs):
+        return obs.deltaPt[0] == 0 and obs.deltaPt[1] < 0
+
+    @staticmethod
+    def _groundValidator(obs):
+        return obs.deltaPt[0] > 0
+
     def setPos(self, pos, attached):
         self.pos = pos
 
@@ -235,16 +280,13 @@ class Player(Unit):
         else:
             if attached == 'l':
                 deltaX, deltaY = -0.5, 0
-                def valid(obs):
-                    return obs.deltaPt[0] == 0 and obs.deltaPt[1] > 0
+                valid = self._leftValidator
             elif attached == 'r':
                 deltaX, deltaY = 0.5, 0
-                def valid(obs):
-                    return obs.deltaPt[0] == 0 and obs.deltaPt[1] < 0
+                valid = self._rightValidator
             else:
                 deltaX, deltaY = 0, 0.5
-                def valid(obs):
-                    return obs.deltaPt[0] > 0
+                valid = self._groundValidator
 
             lastObstacle = None
             # Check for collisions with obstacles - find the closest obstacle.
@@ -275,7 +317,7 @@ class Player(Unit):
         dead = self.ghost
         stars = self.stars
         if self.upgrade:
-            upgrade = repr(self.upgrade)
+            upgrade = str(self.upgrade)
         else:
             upgrade = None
 
@@ -300,16 +342,16 @@ class Player(Unit):
         self.currentMapBlock.removePlayer(self)
         self.currentZone.removePlayer(self)
 
-        # TODO: These lines would be nice, but for now shots are keyed by
-        # player.
-#        for sId, shot in self.shots.iteritems():
-#            shot.originatingPlayer = None
+        # Remove all shots (otherwise we get issues looking up originating
+        # player id.)
+        for shot in self.shots.values():
+            self.universe.removeShot(shot)
 
     def isSolid(self):
         return not self.ghost
 
     def ignoreObstacle(self, obstacle):
-        return self._ignore == obstacle 
+        return self._ignore == obstacle
 
     def continueOffMap(self):
         if not self.ghost:
@@ -400,8 +442,9 @@ class Player(Unit):
             # If we're jumping, cancel the jump.
             # The following line ensures that small jumps are possible
             #  while large jumps still curve.
-            self.yVel = -(1 - self._jumpTime / self.universe.physics.playerMaxJumpTime) * \
-                        self.universe.physics.playerJumpThrust
+            self.yVel = (-(1 - self._jumpTime /
+                    self.universe.physics.playerMaxJumpTime) *
+                    self.universe.physics.playerJumpThrust)
             self._jumpTime = 0
 
     def lookAt(self, angle, thrust=None):
@@ -422,7 +465,8 @@ class Player(Unit):
             self.upgradeGauge -= deltaT
             if self.upgradeGauge <= 0:
                 self.upgrade.timeIsUp()
-                self.universe.eventPlug.send(DeleteUpgradeMsg(self.id, self.upgrade.upgradeType, 'T'))
+                self.universe.eventPlug.send(DeleteUpgradeMsg(self.id,
+                        self.upgrade.upgradeType, 'T'))
 
     def updateGhost(self, deltaT):
         deltaX = (self.universe.physics.playerMaxGhostVel * deltaT *
@@ -507,7 +551,8 @@ class Player(Unit):
             deltaT -= ((oldPos[0]-self.pos[0])**2 +
                     (oldPos[1]-self.pos[1])**2)**0.5 / abs(absVel)
         else:
-            print 'Very very bad thing: motion loop did not terminate after 100 iterations'
+            log.error('Very very bad thing: motion loop did not terminate '
+                    'after 100 iterations')
 
         if obstacle:
             if obstacle.jumpable:
@@ -528,7 +573,7 @@ class Player(Unit):
 
         self._ignore = None
 
-    def setAttachedObstacle(self, obstacle):    
+    def setAttachedObstacle(self, obstacle):
         self.attachedObstacle = obstacle
         if obstacle is None:
             self.motionState = 'fall'
@@ -592,7 +637,8 @@ class Player(Unit):
         obstacle = self.universe.physics.moveUnit(self, deltaX, deltaY)
         if obstacle:
             if obstacle == self._unstickyWall:
-                targetPt = obstacle.unstickyWallFinalPosition(self.pos, deltaX, deltaY)
+                targetPt = obstacle.unstickyWallFinalPosition(self.pos, deltaX,
+                        deltaY)
             else:
                 targetPt = obstacle.finalPosition(self, deltaX, deltaY)
             if targetPt is not None:
@@ -650,8 +696,8 @@ class Player(Unit):
     def changeZone(self, newZone):
         try:
             self.currentZone.removePlayer(self)
-        except:
-            logging.writeException()
+        except Exception, e:
+            log.exception(str(e))
         newZone.addPlayer(self)
         self.currentZone = newZone
 
@@ -668,10 +714,13 @@ class Player(Unit):
     def hurtBy(self, shooterId, shotId, deathType):
         if self.phaseshift or self.turret:
             if shotId != 0:
-                self.universe.eventPlug.send(ShotAbsorbedMsg(self.id, shooterId, shotId))
+                self.universe.eventPlug.send(ShotAbsorbedMsg(self.id,
+                        shooterId, shotId))
         elif self.shielded and self.upgrade.protections <= 1:
-            self.universe.eventPlug.send(ShotAbsorbedMsg(self.id, shooterId, shotId))
-            self.universe.eventPlug.send(DeleteUpgradeMsg(self.id, self.upgrade.upgradeType, 'S'))
+            self.universe.eventPlug.send(ShotAbsorbedMsg(self.id, shooterId,
+                    shotId))
+            self.universe.eventPlug.send(DeleteUpgradeMsg(self.id,
+                    self.upgrade.upgradeType, 'S'))
         elif self.health <= 1:
             self.deathDetected(shooterId, shotId, deathType)
         else:
@@ -682,7 +731,8 @@ class Player(Unit):
         self.universe.eventPlug.send(PlayerKilledMsg(self.id,
                     shooterId, shotId, self.stars, deathType))
         if self.upgrade is not None and self.upgrade.goneWhenDie:
-            self.universe.eventPlug.send(DeleteUpgradeMsg(self.id, self.upgrade.upgradeType, 'D'))
+            self.universe.eventPlug.send(DeleteUpgradeMsg(self.id,
+                    self.upgrade.upgradeType, 'D'))
 
         if self.universe.gameState == GameState.Ended and self.team is not None:
             self.universe.eventPlug.send(SetPlayerTeamMsg(self.id, '\x00'))
@@ -754,7 +804,7 @@ class Player(Unit):
 
     def canShoot(self):
         return self.getShotType() is not None
-    
+
     def makePlayerUpdate(self):
         values = compress_boolean((self._state['left'],
                 self._state['right'], self._state['jump'],
