@@ -51,7 +51,7 @@ from trosnoth.messages import (ChatMsg, TaggingZoneMsg, ShotFiredMsg,
         QueryWorldParametersMsg, PlayerIsReadyMsg, SetPreferredTeamMsg,
         SetPreferredDurationMsg, SetPreferredSizeMsg, CreateCollectableStarMsg,
         RemoveCollectableStarMsg, PlayerHasElephantMsg, ChangeNicknameMsg,
-        FireShoxwaveMsg, MarkZoneMsg, SetGameSpeedMsg)
+        FireShoxwaveMsg, MarkZoneMsg, SetGameSpeedMsg, NotifyUDPStatusMsg)
 
 DIRTY_DELAY = 0.05
 UPDATE_DELAY = 1        # PlayerUpdateMsg is sent for each player this often.
@@ -181,6 +181,7 @@ class Universe(Component):
     @handler(ChatMsg, orderPlug)
     @handler(GrenadeExplosionMsg, orderPlug)
     @handler(QueryWorldParametersMsg, orderPlug)
+    @handler(NotifyUDPStatusMsg, orderPlug)
     def ignore(self, msg):
         pass
 
@@ -517,6 +518,9 @@ class Universe(Component):
             player.removeFromGame()
             self.players.remove(player)
             del self.playerWithId[player.id]
+            if player == self.playerWithElephant:
+                self.returnElephantToOwner()
+
             # In case anyone else keeps a reference to it
             player.id = -1
         except Abort:
@@ -583,10 +587,14 @@ class Universe(Component):
         ePlayerId = '\x00'
         if self.playerWithElephant:
             ePlayerId = self.playerWithElephant.id
+        if isinstance(ePlayerId, str) and len(ePlayerId) == 1:
+            self.eventPlug.send(PlayerHasElephantMsg(ePlayerId))
+        else:
+            log.error('ePlayerId is %r but should be single char', ePlayerId)
+
         if self.gameState != GameState.InProgress:
             return
 
-        self.eventPlug.send(PlayerHasElephantMsg(ePlayerId))
         prob = 0.5 ** ((self._gameTime - self.lastZoneTagged) /
                 ZONE_TAG_STAR_HALF_LIFE)
         if random.random() > prob:
@@ -713,8 +721,9 @@ class Universe(Component):
     def _getNewDuration(self, mapSize):
         results = {}
         for player in self.players:
-            duration = player.preferredDuration
-            results[duration] = results.get(duration, 0) + 1
+            if not player.bot:
+                duration = player.preferredDuration
+                results[duration] = results.get(duration, 0) + 1
         items = results.items()
         items.sort(key=lambda (duration, count): count)
         items.reverse()
@@ -740,8 +749,9 @@ class Universe(Component):
         '''
         results = {}
         for player in self.players:
-            size = player.preferredSize
-            results[size] = results.get(size, 0) + 1
+            if not player.bot:
+                size = player.preferredSize
+                results[size] = results.get(size, 0) + 1
         items = results.items()
         items.sort(key=lambda (size, count): count)
         items.reverse()
@@ -831,9 +841,9 @@ class Universe(Component):
 
     @handler(FireShoxwaveMsg, orderPlug)
     def shoxwaveExplosion(self, msg):
-    	radius = 128
-    	# Get the player who fired this shoxwave
-    	shoxPlayer = self.getPlayer(msg.playerId)
+        radius = 128
+        # Get the player who fired this shoxwave
+        shoxPlayer = self.getPlayer(msg.playerId)
         self._update_reload_time(shoxPlayer)
 
         # Loop through all the players in the game
@@ -850,7 +860,7 @@ class Universe(Component):
         for star in list(self.collectableStars.itervalues()):
             if (not shoxPlayer.isFriendsWithTeam(star.team) and
                     distance(star.pos, shoxPlayer.pos) <= radius):
-               	star.delete()
+                star.delete()
 
 
     @handler(ShotFiredMsg, orderPlug)
@@ -1077,14 +1087,7 @@ class Universe(Component):
                     self.playerWithElephant = killer
                     self.eventPlug.send(PlayerHasElephantMsg(killer.id))
                 else:
-                    for p in self.players:
-                        if p.isElephantOwner():
-                            self.playerWithElephant = p
-                            self.eventPlug.send(PlayerHasElephantMsg(p.id))
-                            break
-                    else:
-                        self.playerWithElephant = None
-                        self.eventPlug.send(PlayerHasElephantMsg('\x00'))
+                    self.returnElephantToOwner()
 
             if self.gameRules == GameRules.Hunting:
                 # Hunt mode
@@ -1108,6 +1111,16 @@ class Universe(Component):
         except Abort:
             pass
 
+    def returnElephantToOwner(self):
+        for p in self.players:
+            if p.isElephantOwner():
+                self.playerWithElephant = p
+                self.eventPlug.send(PlayerHasElephantMsg(p.id))
+                return
+
+        self.playerWithElephant = None
+        self.eventPlug.send(PlayerHasElephantMsg('\x00'))
+
     @handler(TaggingZoneMsg, orderPlug)
     def zoneTagged(self, msg):
         if msg.playerId == '\x00':
