@@ -32,7 +32,7 @@ from trosnoth.messages import (ChatMsg, TaggingZoneMsg, NotifyUDPStatusMsg,
         PlayerIsReadyMsg, SetPreferredTeamMsg, SetPreferredDurationMsg,
         SetPreferredSizeMsg, SetPlayerTeamMsg, CreateCollectableStarMsg,
         RemoveCollectableStarMsg, PlayerHasElephantMsg, ChangeNicknameMsg,
-        MarkZoneMsg, SetGameSpeedMsg)
+        MarkZoneMsg, SetGameSpeedMsg, FireShoxwaveMsg)
 from trosnoth.utils.components import Component, Plug
 from trosnoth.utils.twist import WeakCallLater
 from trosnoth.utils.unrepr import unrepr
@@ -88,6 +88,7 @@ clientMsgs = netmsg.MessageCollection(
     RemoveCollectableStarMsg,
     ChangeNicknameMsg,
     MarkZoneMsg,
+    FireShoxwaveMsg,
 )
 
 class ConnectionFailed(Exception):
