@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,9 +22,9 @@ defaultServerPort = 6789
 
 multicastGroup = '224.0.0.234'
 
-clientVersion = 'client.v1.4.0+'
-serverVersion = 'server.v1.4.0+'
-validServerVersions = set(['server.v1.4.0+'])
+clientVersion = 'client.v1.5.0+'
+serverVersion = 'server.v1.5.0+'
+validServerVersions = set(['server.v1.5.0+'])
 
 defaultSettings = {'halfMapWidth': 3,
                    'mapHeight': 2,
@@ -38,8 +38,6 @@ defaultSettings = {'halfMapWidth': 3,
                    }
 
 validServerAdminIPs = ('127.0.0.1',)
-# TODO: this is nothing to do with network - should not be here.
-maxTeamNameLength = 10
 
 def validServerAdminSender(ip):
     return ip in validServerAdminIPs
