@@ -189,6 +189,11 @@ class AlertSettings(SettingsObject):
     '''
     Stores the Trosnoth authentication server's settings related to when alert
     emails should be sent.
+
+    Settings of the form "alertOnXXX" should have a value of True, False, or an
+    email address. If an email address is given, it is the recipient email
+    address of that kind of alert. If True, the default recipient address is
+    used. If False, no alerts are sent for that alert kind.
     '''
     attributes = (
         ('senderAddress', 'senderAddress', 'trosnoth-server@localhost'),
@@ -217,6 +222,8 @@ class AuthServerSettings(SettingsObject):
         ('privateMsg', 'privateMsg', None),
         ('elephantOwners', 'elephantOwners', ()),
         ('serverName', 'serverName', 'Trosnoth server'),
+        ('homeUrl', 'homeUrl', None),
+        ('hostName', 'hostName', None),
     )
 
     def __init__(self, dataPath):
