@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,15 +20,16 @@ themes.py
 This module defines the interface to the various different themes.
 '''
 
+import logging
 import os
 import pygame
+from random import randrange
 
 from trosnoth import data
 from trosnoth.gui.fonts.font import Font, ScaledFont
 from trosnoth.gui.framework.basics import SingleImage, Animation
 from trosnoth.utils.unrepr import unrepr
-from trosnoth.model.upgrades import (PhaseShift, Turret,
-        MinimapDisruption, Shield, Ricochet, Grenade)
+from trosnoth.model.upgrades import Upgrade
 from trosnoth.utils.utils import timeNow
 
 BLOCK_BACKGROUND_COLOURKEY = (255, 255, 255)
@@ -41,6 +42,7 @@ BLOCK_OFFSETS = {
     'bck': ((-1536, 0), (0, -384)),
 }
 
+log = logging.getLogger('themes')
 
 def teamColour(colourId):
     def colourFunction(self, team):
@@ -62,6 +64,7 @@ class ThemeColours(object):
     miniMapPlayerColour = teamColour('Mn_pl')
     miniMapGhostColour = teamColour('Mn_gh')
     miniMapStarColour = teamColour('Mn_star')
+    miniMapZoneHighlight = teamColour('Mn_highlight')
 
 def cachedProperty(fn):
     def spriteFunction(self):
@@ -112,12 +115,19 @@ class ThemeSprites(object):
     grenade = image('grenade.bmp')
     neutralOrb = image('greyOrb.png')
     scenery = image('scenery.png', colourkey=None)
+    shoxGun3 = image('shoxgun-3.png')
 
+    gunIcon = wrappedImage('gun.png')
     playerBody = wrappedImage('backbone.png')
     elephant = wrappedImage('elephant.png')
+    christmasHat = wrappedImage('christmas.png')
     turretBase = wrappedImage('legs-turret.png')
     playerStanding = wrappedImage('legs-s.png')
     playerJumping = wrappedImage('legs-r3.png')
+    ninjaHead = wrappedImage('ninjahead.png')
+    jammingHatImage = image('jamminghat.png')
+    jammingHatSparks = images(['jamminghat-spark1.png', 'jamminghat-spark2.png',
+            'jamminghat-spark3.png'])
 
     runningLegs = images(['legs-r1.png', 'legs-r2.png',
             'legs-r3.png', 'legs-r4.png'])
@@ -125,10 +135,21 @@ class ThemeSprites(object):
             'legs-w2.png', 'legs-w3.png'])
 
     shieldImages = images(['shieldImage1.png', 'shieldImage2.png',
-            'shieldImage3.png', 'shieldImage4.png'])
+            'shieldImage3.png', 'shieldImage2.png'])
     phaseShiftImages = images(['phaseShift1.png', 'phaseShift2.png',
             'phaseShift3.png', 'phaseShift4.png'])
 
+    @cached
+    def zoneHighlight(self, team, scale):
+        colour = self.theme.colours.miniMapZoneHighlight(team)
+        size = int(300. / scale + 0.5)
+        result = pygame.Surface((2*size, 2*size))
+        result.fill((0,0,0))
+        result.set_colorkey((0,0,0))
+        pygame.draw.circle(result, colour, (size, size), size)
+        result.set_alpha(64)
+        return result
+
     @cached
     def ghostAnimation(self, team):
         if team is not None:
@@ -141,17 +162,54 @@ class ThemeSprites(object):
                 lts('ghost4', 'B'), lts('ghost3', 'A'), lts('ghost2', 'B')]
         return [Animation(0.25, timeNow, *frames)]
 
+    @cached
+    def ghostIcon(self, team):
+        return SingleImage(self.theme.loadTeamSprite('ghost1',
+                getTeamId(team)))
+
     def explosion(self):
-        return Animation(0.07, timeNow, *(self.explosionFrame(i) for i in xrange(4)))
+        return Animation(0.07, timeNow, *(self.explosionFrame(i) for i in
+                xrange(4)))
+
+    def shoxwaveExplosion(self):
+        return Animation(0.05, timeNow, *(self.shoxwaveFrame(i) for i in
+                    xrange(3)))
+
+    def jammingHat(self):
+        images = []
+        for spark in self.jammingHatSparks:
+            images.append(spark)
+            images.extend([self.jammingHatImage] * randrange(5, 15))
+        return Animation(0.05, timeNow, *images)
 
     @cached
     def explosionFrame(self, frame):
         return self.theme.loadSprite('explosion%d.png' % (frame+1,))
 
+    @cached
+    def shoxwaveFrame(self, frame):
+        return self.theme.loadSprite('shoxwave%d.png' % (frame+1,))
+
     @cached
     def playerHolding(self, team):
         return SingleImage(self.theme.loadTeamSprite('hold', getTeamId(team)))
 
+    @cached
+    def machineGunImages(self, team):
+        return self.theme.loadTeamSprites([
+            'machinegun-0', 'machinegun-1', 'machinegun-2',
+            'machinegun-3', 'machinegun-4', 'machinegun-5',
+            'machinegun-6', 'machinegun-7', 'machinegun-8'
+        ], getTeamId(team))
+
+    @cached
+    def ricoGunImages(self, team):
+        return self.theme.loadTeamSprites([
+            'ricogun-0', 'ricogun-1', 'ricogun-2',
+            'ricogun-3', 'ricogun-4', 'ricogun-5',
+            'ricogun-6', 'ricogun-7', 'ricogun-8'
+        ], getTeamId(team))
+
     @cached
     def gunImages(self, team):
         return self.theme.loadTeamSprites([
@@ -161,15 +219,17 @@ class ThemeSprites(object):
         ], getTeamId(team))
 
     @cached
-    def playerHead(self, team):
+    def playerHead(self, team, bot):
         teamId = getTeamId(team)
         if teamId == 'A':
-            path = 'blue.png'
+            path = 'blue'
         elif teamId == 'B':
-            path = 'red.png'
+            path = 'red'
         else:
-            path = 'white.png'
-        return SingleImage(self.theme.loadSprite(path))
+            path = 'white'
+        if bot:
+            path += '-bot'
+        return SingleImage(self.theme.loadSprite(path + '.png'))
 
     @cached
     def collectableStar(self, team):
@@ -196,20 +256,11 @@ class ThemeSprites(object):
 
     @cached
     def upgradeImage(self, upgradeType):
-
-        if upgradeType == PhaseShift:
-            path = 'upgrade-phaseshift.png'
-        if upgradeType == Turret:
-            path = 'upgrade-turret.png'
-        if upgradeType == Shield:
-            path = 'upgrade-shield.png'
-        if upgradeType == MinimapDisruption:
-            path = 'upgrade-minimap.png'
-        if upgradeType == Grenade:
-            path = 'upgrade-grenade.png'
-        if upgradeType == Ricochet:
-            path = 'upgrade-ricochet.png'
-        return self.theme.loadSprite(path)
+        assert issubclass(upgradeType, Upgrade)
+        path = upgradeType.iconPath
+        if path is None:
+            path = 'upgrade-unknown.png'
+        return self.theme.loadSprite(path, colourkey=upgradeType.iconColourKey)
 
     def blockBackground(self, block):
         return self.getBlockBackground(block, 'zone.png')
@@ -339,7 +390,6 @@ class Theme(object):
             setattr(self.colours, colourName, colour)
 
     def initSounds(self):
-        # TODO: actual sounds
         self.app.soundPlayer.addSound('buyUpgrade.ogg', 'buyUpgrade', 1)
         self.app.soundPlayer.addSound('gameLose.ogg', 'gameLose', 1)
         self.app.soundPlayer.addSound('startGame.ogg', 'startGame', 1)
@@ -374,7 +424,7 @@ class Theme(object):
             bits[2] = bits[2].strip()
             # Perform basic checks
             if len(bits) != 3 or not bits[2].isdigit():
-                print 'Invalid font config line: %r' % (line,)
+                log.warning('Invalid font config line: %r', line)
             else:
                 result[bits[0]] = (bits[1], int(bits[2]))
         return result
@@ -410,7 +460,7 @@ class Theme(object):
                                 len(colour) > 4):
                             invalid = True
             if invalid:
-                print 'Invalid colour config line: %r' % (line,)
+                log.warning('Invalid colour config line: %r', line)
             else:
                 result[bits[0].strip()] = colour
         return result
