@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,8 +15,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import logging
 import random
 
+import pygame
+
 from trosnoth.gui.framework import framework
 from trosnoth.gui.framework.elements import PictureElement
 from trosnoth.gui.common import (Location, FullScreenAttachedPoint,
@@ -28,21 +31,21 @@ from trosnoth.trosnothgui.ingame.stars import StarGroup
 from trosnoth.trosnothgui.ingame.udpnotify import UDPNotificationBar
 from trosnoth.trosnothgui.ingame import mainMenu
 from trosnoth.trosnothgui.ingame.gamevote import GameVoteMenu, NicknameBox
-from trosnoth.trosnothgui.ingame.gauges import TurretGauge, RespawnGauge, \
-                                                   UpgradeGauge
+from trosnoth.trosnothgui.ingame.gauges import (TurretGauge, RespawnGauge,
+        UpgradeGauge, GunGauge, StarGauge)
 from trosnoth.trosnothgui.ingame.achievementBox import AchievementBox
 from trosnoth.gui.framework.dialogbox import DialogResult
-from trosnoth.trosnothgui.pregame.settingsMenu import SettingsMenu
+from trosnoth.trosnothgui.settings.settings import SettingsMenu
 
-from trosnoth.base import MenuError
-from trosnoth.model.upgrades import Turret, Shield, MinimapDisruption, \
-                                        PhaseShift, Grenade, Ricochet
+from trosnoth.model.upgrades import allUpgrades, Grenade
 from trosnoth.model.universe_base import GameState
 from trosnoth.model.team import Team
 from trosnoth.model.player import Player
 
 from trosnoth.messages import (BuyUpgradeMsg, DeleteUpgradeMsg, SetCaptainMsg,
-        TeamIsReadyMsg, RespawnRequestMsg, ChangeNicknameMsg)
+        TeamIsReadyMsg, RespawnRequestMsg, ChangeNicknameMsg, MarkZoneMsg)
+
+log = logging.getLogger('detailsInterface')
 
 class DetailsInterface(framework.CompoundElement):
     '''Interface containing all the overlays onto the screen:
@@ -57,32 +60,45 @@ class DetailsInterface(framework.CompoundElement):
 
         self.world = world
         self.player = None
+        font = app.screenManager.fonts.messageFont
         self.currentMessages = MessageBank(self.app, maxView, 50,
-                                           Location(FullScreenAttachedPoint(ScaledSize(-40,-40),'bottomright'), 'bottomright'),
-                                           'right', 'bottom',
-                                           self.app.screenManager.fonts.messageFont)
-        self.currentChats = MessageBank(self.app, maxView, 50, Location(FullScreenAttachedPoint(ScaledSize(40,256),'topleft'), 'topleft'), 'left', 'top',
-                                        self.app.screenManager.fonts.messageFont)
+                Location(FullScreenAttachedPoint(ScaledSize(-40,-40),
+                'bottomright'), 'bottomright'), 'right', 'bottom', font)
+        self.currentChats = MessageBank(self.app, maxView, 50,
+                Location(FullScreenAttachedPoint(ScaledSize(40,256),'topleft'),
+                'topleft'), 'left', 'top', font)
+
         # If we want to keep a record of all messages and their senders
         self.input = None
         self.inputText = None
         self.unobtrusiveGetter = None
         self.turretGauge = None
+        self.reloadGauge = GunGauge(self.app, Area(
+                FullScreenAttachedPoint(ScaledSize(0,-60), 'midbottom'),
+                ScaledSize(100,30), 'midbottom'))
         self.respawnGauge = None
         self.upgradeGauge = None
         self.achievementBox = None
         self.currentUpgrade = None
         self.starGroup = StarGroup(self.app)
         self.udpNotifier = UDPNotificationBar(self.app)
-        self.settingsMenu = SettingsMenu(app, onClose=self.hideSettings, showThemes=False)
+        self.settingsMenu = SettingsMenu(app, onClose=self.hideSettings,
+                showThemes=False)
 
-        menuloc = Location(FullScreenAttachedPoint((0,0), 'bottomleft'), 'bottomleft')
-        self.menuManager = mainMenu.MainMenu(self.app, menuloc, self, self.gameInterface.keyMapping)
+        menuloc = Location(FullScreenAttachedPoint((0,0), 'bottomleft'),
+                'bottomleft')
+        self.menuManager = mainMenu.MainMenu(self.app, menuloc, self,
+                self.gameInterface.keyMapping)
         self.upgradeDisplay = UpgradeDisplay(app)
-        self.gameVoteMenu = GameVoteMenu(app, world, onChange=self._castGameVote)
+        self.gameVoteMenu = GameVoteMenu(app, world,
+                onChange=self._castGameVote)
         self._gameVoteUpdateCounter = 0
-        self.elements = [self.currentMessages, self.currentChats, self.upgradeDisplay,
-                         self.starGroup, self.gameVoteMenu, self.udpNotifier]
+        self.elements = [self.currentMessages, self.currentChats,
+                self.upgradeDisplay, self.reloadGauge, self.starGroup,
+                self.gameVoteMenu, self.udpNotifier]
+
+        self.upgradeMap = dict((upgradeClass.action, upgradeClass) for
+                upgradeClass in allUpgrades)
 
     @property
     def controller(self):
@@ -110,7 +126,7 @@ class DetailsInterface(framework.CompoundElement):
         self.controller.send(msg)
 
     def _updateGameVoteMenu(self):
-        if self.world.gameState == GameState.Ended:
+        if self.world.gameState == GameState.Ended and not self.world.onceOnly:
             self.gameVoteMenu.active = True
         else:
             self.gameVoteMenu.active = False
@@ -124,8 +140,8 @@ class DetailsInterface(framework.CompoundElement):
             self.achievementBox.addAchievement(achievementId)
 
     def _updateAchievementBox(self):
-        if self.achievementBox is not None \
-           and len(self.achievementBox.achievements) == 0:
+        if (self.achievementBox is not None and
+                len(self.achievementBox.achievements) == 0):
             self.elements.remove(self.achievementBox)
             self.achievementBox = None
 
@@ -134,14 +150,14 @@ class DetailsInterface(framework.CompoundElement):
         if self.turretGauge is None:
             if player.turret:
                 self.turretGauge = TurretGauge(self.app, Area(
-                        FullScreenAttachedPoint(ScaledSize(0,-60),
+                        FullScreenAttachedPoint(ScaledSize(0,-100),
                         'midbottom'), ScaledSize(100,30), 'midbottom'),
                         player)
                 self.elements.append(self.turretGauge)
         elif not player.turret:
             self.elements.remove(self.turretGauge)
             self.turretGauge = None
-            
+
     def _updateRespawnGauge(self):
         player = self.player
         if self.respawnGauge is None:
@@ -154,7 +170,7 @@ class DetailsInterface(framework.CompoundElement):
         elif not player.ghost:
             self.elements.remove(self.respawnGauge)
             self.respawnGauge = None
-            
+
     def _updateUpgradeGauge(self):
         player = self.player
         if self.upgradeGauge is None:
@@ -173,6 +189,7 @@ class DetailsInterface(framework.CompoundElement):
 
     def setPlayer(self, player):
         self.player = player
+        self.reloadGauge.player = player
         if self.menuManager not in self.elements:
             self.elements.append(self.menuManager)
 
@@ -187,8 +204,9 @@ class DetailsInterface(framework.CompoundElement):
 
     def _setCurrentUpgrade(self, upgradeType):
         self.currentUpgrade = upgradeType
-        self.upgradeDisplay.setUpgrade(self.currentUpgrade)
-        
+        self.upgradeDisplay.setUpgrade(self.currentUpgrade, self.player)
+        self.menuManager.manager.reset()
+
     def _requestUpgrade(self):
         if self.currentUpgrade is not None:
             self.controller.send(BuyUpgradeMsg(self.player.id,
@@ -207,8 +225,19 @@ class DetailsInterface(framework.CompoundElement):
                 nickname = prompt.value
                 self.controller.send(ChangeNicknameMsg(self.player.id,
                         nickname.encode()))
-            
-        prompt.Show()
+
+        prompt.show()
+
+    def markZone(self):
+        zone = self.getZoneAtCursor()
+        if zone is None:
+            return
+        self.controller.send(MarkZoneMsg(self.player.id, zone.id, not
+                zone.markedBy.get(self.player.team, False)))
+
+    def getZoneAtCursor(self):
+        return self.gameInterface.gameViewer.getZoneAtPoint(
+                pygame.mouse.get_pos())
 
     def doAction(self, action):
         '''
@@ -249,24 +278,8 @@ class DetailsInterface(framework.CompoundElement):
             if action == 'respawn':
                 self.controller.send(RespawnRequestMsg(self.player.id,
                         random.randrange(1<<32)))
-            elif action == 'turret':
-                self._setCurrentUpgrade(Turret)
-                self.menuManager.manager.reset()
-            elif action == 'shield':
-                self._setCurrentUpgrade(Shield)
-                self.menuManager.manager.reset()
-            elif action == 'minimap disruption':
-                self._setCurrentUpgrade(MinimapDisruption)
-                self.menuManager.manager.reset()
-            elif action == 'phase shift':
-                self._setCurrentUpgrade(PhaseShift)
-                self.menuManager.manager.reset()
-            elif action == 'grenade':
-                self._setCurrentUpgrade(Grenade)
-                self.menuManager.manager.reset()
-            elif action == 'ricochet':
-                self._setCurrentUpgrade(Ricochet)
-                self.menuManager.manager.reset()
+            elif action in self.upgradeMap:
+                self._setCurrentUpgrade(self.upgradeMap[action])
             elif action == 'no upgrade':
                 self._setCurrentUpgrade(None)
                 self.menuManager.manager.reset()
@@ -282,15 +295,17 @@ class DetailsInterface(framework.CompoundElement):
             elif action == 'team ready':
                 self.teamReady()
                 self.menuManager.manager.reset()
-            elif action == 'buy upgrade':
+            elif action == 'select upgrade':
                 if self.menuManager is not None:
                     self.menuManager.showBuyMenu()
             elif action == 'activate upgrade':
                 self._requestUpgrade()
             elif action == 'change nickname':
                 self._changeNickname()
+            elif action == 'mark zone':
+                self.markZone()
             elif action not in ('jump', 'right', 'left', 'down'):
-                print 'Unknown action: %r' % (action,)
+                log.warning('Unknown action: %r', action)
 
     def newMessage(self, text, colour=None):
         if colour is None:
@@ -311,14 +326,13 @@ class DetailsInterface(framework.CompoundElement):
             # Destined for the one player
             extra = ' (private): '
 
-        elif isinstance(private, Team) and self.player is not None and \
-                self.player.team == private:
+        elif (isinstance(private, Team) and self.player is not None and
+                self.player.team == private):
             # Destined for the one team.
             extra = ': '
 
         else:
             # May not have been destined for our player after all.
-            print "Don't want this text"
             return
         allText = nick + extra + text
         self.currentChats.newMessage(allText,
@@ -336,24 +350,6 @@ class DetailsInterface(framework.CompoundElement):
         self.currentChats.newMessage('Me: %s' % (text,),
                 self.app.theme.colours.chatColour(team))
 
-    def processEvent(self, event):
-        '''Event processing works in the following way:
-        1. If there is a prompt on screen, the prompt will either use the
-        event, or pass it on.
-        2. If passed on, the event will be sent back to the main class, for it
-        to process whether player movement uses this event. If it doesn't use
-        the event, it will pass it back.
-        3. If so, the hotkey manager will see if the event means anything to it.
-        If not, that's the end, the event is ignored.'''
-
-        try:
-            return super(DetailsInterface, self).processEvent(event)
-        except MenuError, err:
-            self.newMessage(err.value, self.app.theme.colours.errorMessageColour)
-            self.endInput()
-            return None
-
-
     def endInput(self):
         if self.input:
             self.elements.remove(self.input)
@@ -364,7 +360,8 @@ class DetailsInterface(framework.CompoundElement):
         if self.unobtrusiveGetter:
             self.elements.remove(self.unobtrusiveGetter)
             self.unobtrusiveGetter = None
-        if self.menuManager is not None and self.menuManager not in self.elements:
+        if (self.menuManager is not None and self.menuManager not in
+                self.elements):
             self.elements.append(self.menuManager)
         self.input = self.inputText = None
 
@@ -398,8 +395,7 @@ class DetailsInterface(framework.CompoundElement):
             if type(player.upgrade) == Grenade:
                 self.newMessage('Cannot abandon an active grenade!',
                         self.app.theme.colours.errorMessageColour)
-                raise MenuError, "Cannot abandon an active grenade!"
-
+                return
         else:
             return
 
@@ -416,7 +412,8 @@ class DetailsInterface(framework.CompoundElement):
                 self.elements.remove(self.unobtrusiveGetter)
                 self.unobtrusiveGetter = None
             if abandon:
-                self.controller.send(DeleteUpgradeMsg(player.id, player.upgrade.upgradeType, 'A'))
+                self.controller.send(DeleteUpgradeMsg(player.id,
+                        player.upgrade.upgradeType, 'A'))
 
         self.unobtrusiveGetter.onGotValue.addListener(gotValue)
 
@@ -426,7 +423,7 @@ class DetailsInterface(framework.CompoundElement):
         if upgrade is None:
             upgrade = 'an upgrade'
         else:
-            upgrade = repr(upgrade)
+            upgrade = str(upgrade)
         message = '%s is using %s' % (player.nick, player.upgrade)
         self.newMessage(message)
 
@@ -434,7 +431,7 @@ class DetailsInterface(framework.CompoundElement):
         if upgrade is None:
             upgrade = 'upgrade'
         else:
-            upgrade = repr(upgrade)
+            upgrade = str(upgrade)
         message = "%s's %s is gone" % (player.nick, upgrade)
         self.newMessage(message)
 
@@ -457,10 +454,17 @@ class UpgradeDisplay(framework.CompoundElement):
     def __init__(self, app):
         super(UpgradeDisplay, self).__init__(app)
 
-    def setUpgrade(self, upgradeType):
-        if upgradeType is None:
+    def setUpgrade(self, upgradeType, player):
+        if player is None or upgradeType is None:
             self.elements = []
         else:
             pos = Location(Canvas(620, 0), "midtop")
             image = self.app.theme.sprites.upgradeImage(upgradeType)
-            self.elements = [PictureElement(self.app, image, pos)]
+            area = Area(
+                    Canvas(620, 68),
+                    #FullScreenAttachedPoint(ScaledSize(620, 20), 'topleft'),
+                    ScaledSize(50, 10), 'midbottom')
+            self.elements = [
+                PictureElement(self.app, image, pos),
+                StarGauge(self.app, area, player, upgradeType)
+            ]
