@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,18 +22,18 @@ from trosnoth.gui.framework import framework, hotkey, console
 from trosnoth.gui.framework.elements import TextElement
 from trosnoth.gui import keyboard
 from trosnoth.gui.common import Region, Screen, Location, Canvas
-from trosnoth.gui.screenManager.windowManager import MultiWindowException
+from trosnoth.gui.errors import MultiWindowException
 
 from trosnoth.gamerecording.achievementlist import getAchievementDetails
 
 from trosnoth.trosnothgui.ingame import viewManager
-from trosnoth.trosnothgui.ingame.replayInterface import ReplayMenu, ViewControlInterface
+from trosnoth.trosnothgui.ingame.replayInterface import (ReplayMenu,
+        ViewControlInterface)
 from trosnoth.trosnothgui.ingame.gameMenu import GameMenu
 from trosnoth.trosnothgui.ingame.detailsInterface import DetailsInterface
 from trosnoth.trosnothgui.ingame.observerInterface import ObserverInterface
 from trosnoth.trosnothgui.ingame.playerInterface import PlayerInterface
 
-from trosnoth.base import MenuError
 from trosnoth import keymap
 
 from trosnoth.data import user, getPath
@@ -44,23 +44,19 @@ from trosnoth.model.universe import Abort
 
 from trosnoth.utils.math import distance
 from trosnoth.utils.event import Event
+from trosnoth.utils.twist import WeakCallLater
 
 from trosnoth.messages import (TaggingZoneMsg, ChatFromServerMsg, ChatMsg,
         GameStartMsg, GameOverMsg, TeamIsReadyMsg, SetCaptainMsg,
-        ShotAbsorbedMsg, StartingSoonMsg, SetTeamNameMsg, SetGameModeMsg,
-        ShotFiredMsg, KillShotMsg, RespawnMsg, CannotRespawnMsg,
-        PlayerKilledMsg, PlayerUpdateMsg, PlayerHitMsg, JoinRequestMsg,
-        JoinSuccessfulMsg, CannotJoinMsg, AddPlayerMsg, UpdatePlayerStateMsg,
-        AimPlayerAtMsg, RemovePlayerMsg, PlayerHasUpgradeMsg,
+        StartingSoonMsg, ShotFiredMsg, RespawnMsg, CannotRespawnMsg,
+        PlayerKilledMsg, JoinRequestMsg, JoinSuccessfulMsg, CannotJoinMsg,
+        AddPlayerMsg, RemovePlayerMsg, PlayerHasUpgradeMsg,
         WorldParametersReceived, PlayerStarsSpentMsg, DeleteUpgradeMsg,
         CannotBuyUpgradeMsg, ConnectionLostMsg, NotifyUDPStatusMsg,
-        GrenadeExplosionMsg, AchievementUnlockedMsg, ZoneStateMsg,
-        WorldResetMsg, PlayerIsReadyMsg, SetPreferredTeamMsg,
-        SetPreferredSizeMsg, SetPreferredDurationMsg, SetPlayerTeamMsg,
-        CreateCollectableStarMsg, RemoveCollectableStarMsg,
-        PlayerHasElephantMsg, ChangeNicknameMsg)
+        GrenadeExplosionMsg, AchievementUnlockedMsg, WorldResetMsg,
+        SetPlayerTeamMsg, PlayerHasElephantMsg, FireShoxwaveMsg, MarkZoneMsg)
 
-from twisted.internet import defer, reactor
+from twisted.internet import defer
 
 class GameInterface(framework.CompoundElement, Component):
     '''Interface for when we are connected to a game.'''
@@ -81,7 +77,7 @@ class GameInterface(framework.CompoundElement, Component):
         self.onConnectionLost = Event()
         if onConnectionLost is not None:
             self.onConnectionLost.addListener(onConnectionLost)
-            
+
         self.world = world
 
         self.keyMapping = keyboard.KeyboardMapping(keymap.default_game_keys)
@@ -121,23 +117,7 @@ class GameInterface(framework.CompoundElement, Component):
             self.elements.append(self.vcInterface)
             self.hideMenu()
 
-
-    @handler(SetTeamNameMsg, eventPlug)
-    @handler(UpdatePlayerStateMsg, eventPlug)
-    @handler(AimPlayerAtMsg, eventPlug)
-    @handler(SetGameModeMsg, eventPlug)
-    @handler(PlayerUpdateMsg, eventPlug)
-    @handler(ZoneStateMsg, eventPlug)
-    @handler(PlayerIsReadyMsg, eventPlug)
-    @handler(SetPreferredTeamMsg, eventPlug)
-    @handler(SetPreferredDurationMsg, eventPlug)
-    @handler(SetPreferredSizeMsg, eventPlug)
-    @handler(CreateCollectableStarMsg, eventPlug)
-    @handler(RemoveCollectableStarMsg, eventPlug)    
-    @handler(ShotAbsorbedMsg, eventPlug)
-    @handler(PlayerHitMsg, eventPlug)
-    @handler(KillShotMsg, eventPlug)
-    @handler(ChangeNicknameMsg, eventPlug)
+    @eventPlug.defaultHandler
     def ignoreMessage(self, msg):
         pass
 
@@ -178,7 +158,8 @@ class GameInterface(framework.CompoundElement, Component):
     def showMenu(self):
         if self.runningPlayerInterface is not None:
             if self.runningPlayerInterface.player is not None:
-                # Can't get to this particular menu after you've joined the game.
+                # Can't get to this particular menu after you've joined the
+                # game.
                 return
         self.elements = [self.gameViewer, self.gameMenu]
         self.menuShowing = True
@@ -242,13 +223,13 @@ class GameInterface(framework.CompoundElement, Component):
         self.controller.send(JoinRequestMsg(teamId, random.randrange(1<<32),
                 nick=nick.encode(), authTag=self.authTag, bot=False))
         self.joiningDeferred = result
-        reactor.callLater(timeout, self._joinTimedOut)
+        WeakCallLater(timeout, self, '_joinTimedOut')
 
         return result
 
     @handler(JoinSuccessfulMsg, eventPlug)
     def joinedOk(self, msg):
-        reactor.callLater(0, self._joinedOk, msg)
+        WeakCallLater(0, self, '_joinedOk', msg)
 
     def _joinedOk(self, msg):
         d = self.joiningDeferred
@@ -259,7 +240,7 @@ class GameInterface(framework.CompoundElement, Component):
             player = self.world.playerWithId[msg.playerId]
         except KeyError:
             # Retry until the timeout cancels it.
-            reactor.callLater(0.5, self._joinedOk, msg)
+            WeakCallLater(0.5, self, '_joinedOk', msg)
         else:
             d.callback(('success', player))
             self.joiningDeferred = None
@@ -315,16 +296,6 @@ class GameInterface(framework.CompoundElement, Component):
             self.winnerMsg.setText('Game drawn')
             self.winnerMsg.setColour((128, 128, 128))
 
-    def processEvent(self, event):
-        try:
-            return super(GameInterface, self).processEvent(event)
-        except MenuError, err:
-            self.detailsInterface.newMessage(err.value,
-                    self.app.theme.colours.errorMessageColour)
-            self.detailsInterface.endInput()
-            return None
-
-
     @handler(PlayerStarsSpentMsg, eventPlug)
     def discard(self, msg):
         pass
@@ -340,6 +311,17 @@ class GameInterface(framework.CompoundElement, Component):
         except Abort:
             pass
 
+    @handler(MarkZoneMsg, eventPlug)
+    def markZone(self, msg):
+        try:
+            if msg.value:
+                player = self.world.getPlayer(msg.playerId)
+                zone = self.world.getZone(msg.zoneId)
+                self.detailsInterface.newMessage('%s has marked %s' % (player,
+                        zone))
+        except Abort:
+            pass
+
     @handler(AddPlayerMsg, eventPlug)
     def addPlayer(self, msg):
         try:
@@ -430,6 +412,8 @@ class GameInterface(framework.CompoundElement, Component):
                 text = 'You are too close to the orb.'
             elif msg.reasonId == 'F':
                 text = 'You are not in a dark friendly zone.'
+            elif msg.reasonId == 'I':
+                text = 'Upgrade not recognised by server.'
             else:
                 text = 'You cannot buy that upgrade at this time.'
             self.detailsInterface.newMessage(text)
@@ -455,7 +439,7 @@ class GameInterface(framework.CompoundElement, Component):
             player = self.world.getPlayer(msg.playerId)
             self.detailsInterface.upgradeDestroyed(player, player.upgrade)
         except Abort:
-            print 'Unable to remove upgrade: %s' % (msg.playerId,)
+            pass
 
     @handler(ChatFromServerMsg, eventPlug)
     def gotChatFromServer(self, msg):
@@ -463,7 +447,8 @@ class GameInterface(framework.CompoundElement, Component):
 
     @handler(StartingSoonMsg, eventPlug)
     def startingSoon(self, msg):
-        self.detailsInterface.newMessage('Both teams are ready. Game starting in %d seconds' % msg.delay)
+        self.detailsInterface.newMessage('Both teams are ready. '
+                'Game starting in %d seconds' % msg.delay)
 
     @handler(TaggingZoneMsg, eventPlug)
     def zoneTagged(self, msg):
@@ -575,15 +560,15 @@ class GameInterface(framework.CompoundElement, Component):
         except Abort:
             return
         achievementName = getAchievementDetails(msg.achievementId)[0]
-        self.detailsInterface.newMessage('%s has unlocked "%s"!' % \
-                                         (player.nick, achievementName),
-                                         self.app.theme.colours.achievementMessageColour)
+        self.detailsInterface.newMessage('%s has unlocked "%s"!' %
+                (player.nick, achievementName),
+                self.app.theme.colours.achievementMessageColour)
 
         focusPlayer = self.detailsInterface.player
         if (focusPlayer is not None and focusPlayer.id == msg.playerId):
             self.detailsInterface.localAchievement(msg.achievementId)
             #self.playSound('achievement', 1)
-        
+
 
     @handler(ShotFiredMsg, eventPlug)
     def shotFired(self, msg):
@@ -601,6 +586,10 @@ class GameInterface(framework.CompoundElement, Component):
         dist = self.distance((msg.xpos, msg.ypos))
         self.playSound('explodeGrenade', self.getSoundVolume(dist))
 
+    @handler(FireShoxwaveMsg, eventPlug)
+    def shoxwaveExplosion(self, msg):
+    	self.gameViewer.worldgui.addShoxwaveExplosion((msg.xpos, msg.ypos))
+
     @handler(NotifyUDPStatusMsg, eventPlug)
     def udpStatusChanged(self, msg):
         if msg.connected:
