@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,11 +19,11 @@
 state of a universe to the screen.'''
 
 from math import sin, cos
+import logging
 
 import pygame
 
 from trosnoth.utils.utils import timeNow
-from trosnoth.utils.logging import writeException
 from trosnoth.trosnothgui.ingame.minimap import MiniMap
 from trosnoth.gui.framework import framework, elements
 from trosnoth.trosnothgui.ingame.leaderboard import LeaderBoard
@@ -31,9 +31,10 @@ from trosnoth.trosnothgui.ingame.statusBar import ZoneProgressBar
 from trosnoth.trosnothgui.ingame.gameTimer import GameTimer
 from trosnoth.trosnothgui.ingame.chatBox import ChatBox
 from trosnoth.trosnothgui.ingame.universegui import UniverseGUI
-from trosnoth.model.universe_base import GameState
-
 from trosnoth.model.map import MapLayout
+from trosnoth.model.universe_base import GameState
+from trosnoth.model.utils import getZonesInRect, getBlocksInRect
+
 from trosnoth.model.player import Player
 
 from trosnoth.gui.common import Location, FullScreenAttachedPoint
@@ -50,6 +51,8 @@ INTERFACE_BLOCK_SIZE = (512, 384)
 
 BACKDROP_COLOUR_KEY = (255, 255, 255)
 
+log = logging.getLogger('viewManager')
+
 class ViewManager(framework.Element):
     '''A ViewManager object takes a given universe, and displays a screenfull
     of the current state of the universe on the specified screen object.  This
@@ -136,7 +139,7 @@ class ViewManager(framework.Element):
             screen.fill((0, 0, 0))
 
         oldClip = screen.get_clip()
-        
+
         screen.set_clip(self.sRect)
         self.backgroundDrawer.draw(screen, self.sRect, self._focus)
         self._drawSprites(screen)
@@ -150,30 +153,31 @@ class ViewManager(framework.Element):
         ntGroup = pygame.sprite.Group()
         visPlayers = pygame.sprite.Group()
         for player in self.universe.iterPlayers():
-            # Calculate the position of the player.
-            player.rect.center = [player.pos[i] - focus[i] + \
-                    area.center[i] for i in (0,1)]
+            if not player.invisible or player.isFriendsWith(self.target):
+                # Calculate the position of the player.
+                player.rect.center = [player.pos[i] - focus[i] + area.center[i]
+                        for i in (0, 1)]
 
-            # Check if this player needs its nametag shown.
-            if player.rect.colliderect(area):
-                visPlayers.add(player)
-                player.nametag.rect.midtop = player.rect.midbottom
-                # Check that entire nametag's on screen.
-                if player.nametag.rect.left < area.left:
-                    player.nametag.rect.left = area.left
-                elif player.nametag.rect.right > area.right:
-                    player.nametag.rect.right = area.right
-                if player.nametag.rect.top < area.top:
-                    player.nametag.rect.top = area.top
-                elif player.nametag.rect.bottom > area.bottom:
-                    player.nametag.rect.bottom = area.bottom
-                ntGroup.add(player.nametag)
+                # Check if this player needs its nametag shown.
+                if player.rect.colliderect(area):
+                    visPlayers.add(player)
+                    player.nametag.rect.midtop = player.rect.midbottom
+                    # Check that entire nametag's on screen.
+                    if player.nametag.rect.left < area.left:
+                        player.nametag.rect.left = area.left
+                    elif player.nametag.rect.right > area.right:
+                        player.nametag.rect.right = area.right
+                    if player.nametag.rect.top < area.top:
+                        player.nametag.rect.top = area.top
+                    elif player.nametag.rect.bottom > area.bottom:
+                        player.nametag.rect.bottom = area.bottom
+                    ntGroup.add(player.nametag)
 
-                # Place the star rectangle below the nametag.
-                mx, my = player.nametag.rect.midbottom
-                player.starTally.setStars(player.stars)
-                player.starTally.rect.midtop = (mx, my-5)
-                ntGroup.add(player.starTally)
+                    # Place the star rectangle below the nametag.
+                    mx, my = player.nametag.rect.midbottom
+                    player.starTally.setStars(player.stars)
+                    player.starTally.rect.midtop = (mx, my-5)
+                    ntGroup.add(player.starTally)
 
         # Draw the on-screen players and nametags.
         visPlayers.draw(screen)
@@ -182,8 +186,8 @@ class ViewManager(framework.Element):
 
         def drawSprite(sprite):
             # Calculate the position of the sprite.
-            sprite.rect.center = [sprite.pos[i] - focus[i] + \
-                    area.center[i] for i in (0,1)]
+            sprite.rect.center = [sprite.pos[i] - focus[i] + area.center[i] for
+                    i in (0, 1)]
             if sprite.rect.colliderect(area):
                 screen.blit(sprite.image, sprite.rect)
 
@@ -192,13 +196,13 @@ class ViewManager(framework.Element):
             drawSprite(shot)
         for star in self.universe.iterCollectableStars():
             drawSprite(star)
-        
+
         try:
             # Draw the grenades.
             for grenade in self.universe.iterGrenades():
                 drawSprite(grenade)
-        except:
-            writeException()
+        except Exception, e:
+            log.exception(str(e))
 
         for sprite in self.universe.iterExtras():
             drawSprite(sprite)
@@ -284,9 +288,9 @@ class ViewManager(framework.Element):
 
                 # Look at centre-of-range of these players.
                 if len(players) > 0:
-                    minPos = [min(p.pos[i] for p in players) for i in (0,1)]
-                    maxPos = [max(p.pos[i] for p in players) for i in (0,1)]
-                    targetPt = [0.5 * (minPos[i] + maxPos[i]) for i in (0,1)]
+                    minPos = [min(p.pos[i] for p in players) for i in (0, 1)]
+                    maxPos = [max(p.pos[i] for p in players) for i in (0, 1)]
+                    targetPt = [0.5 * (minPos[i] + maxPos[i]) for i in (0, 1)]
             self.autoFocusInfo = (countdown, players)
 
         # Calculate time that's passed.
@@ -296,7 +300,7 @@ class ViewManager(framework.Element):
 
         # Calculate distance to target.
         self._oldTargetPt = targetPt
-        sTarget = sum((targetPt[i] - self._focus[i])**2 for i in (0,1)) ** 0.5
+        sTarget = sum((targetPt[i] - self._focus[i])**2 for i in (0, 1)) ** 0.5
 
         if sTarget == 0:
             return (0, 0)
@@ -311,20 +315,29 @@ class ViewManager(framework.Element):
             vDecel = (2. * self.acceleration * sTarget) ** 0.5
 
             # Actual velocity is limited by this and maximum velocity.
-            self.speed = min(self.maxSpeed, vDecel, \
-                             self.speed + self.acceleration * deltaT)
+            self.speed = min(self.maxSpeed, vDecel, self.speed +
+                    self.acceleration * deltaT)
 
             # Distance travelled should never overshoot the target.
             s = min(sTarget, self.speed * deltaT)
 
         # How far does the backdrop need to move by?
         #  (This will be negative what the focus moves by.)
-        deltaBackdrop = tuple(round(-s * (targetPt[i] - self._focus[i]) \
-                                    / sTarget, 0) for i in (0,1))
+        deltaBackdrop = tuple(round(-s * (targetPt[i] - self._focus[i]) /
+                sTarget, 0) for i in (0, 1))
 
         # Calculate the new focus.
-        self._focus = tuple(round(self._focus[i] - deltaBackdrop[i], 0) \
-                            for i in (0,1))
+        self._focus = tuple(round(self._focus[i] - deltaBackdrop[i], 0) for i
+                in (0, 1))
+
+    def getZoneAtPoint(self, pt):
+        x, y = screenToMapPos(pt, self._focus, self.sRect)
+
+        i, j = MapLayout.getMapBlockIndices(x, y)
+        try:
+            return self.universe.map.zoneBlocks[i][j].getZoneAtPoint(x, y)
+        except IndexError:
+            return None
 
 class BackgroundDrawer(object):
     def __init__(self, app, universe):
@@ -365,7 +378,8 @@ class Scenery(object):
                 continue
 
             r = WINDOW_RECT[bd.kind]
-            regions.append(pygame.Rect(r[0] + pos[0], r[1] + pos[1], r[2], r[3]))
+            regions.append(pygame.Rect(r[0] + pos[0], r[1] + pos[1], r[2],
+                    r[3]))
 
         x0, y0 = mapPosToScreen((0, 0), focus, area)
         if area.top < y0:
@@ -537,42 +551,15 @@ def mapPosToScreen(pt, focus, area):
     return (pt[0] - focus[0] + area.centerx,
             pt[1] - focus[1] + area.centery)
 
-def getBlocksInRect(world, rect):
-    i, j0 = MapLayout.getMapBlockIndices(rect.left, rect.top)
-    j0 = max(0, j0)
-    i = max(0, i)
-
-    while i < len(world.zoneBlocks):
-        row = world.zoneBlocks[i]
-        j = j0
-        while j < len(row):
-            block = row[j]
-            blockLeft, blockTop = block.defn.pos
-            if blockTop >= rect.bottom:
-                return
-            if blockLeft >= rect.right:
-                break
-            yield block
-            j += 1
-        i += 1
-
-def getZonesInRect(world, rect):
-    '''
-    This will yield all zones which are in map blocks in the given rect.
-    Note that sometimes a zone will be yielded that is not quite in the rect, if
-    one of the zone's map blocks is in the rect.
-    '''
-    touchedZones = set()
-    for block in getBlocksInRect(world, rect):
-        for zone in block.getZones():
-            if zone not in touchedZones:
-                touchedZones.add(zone)
-                yield zone
+def screenToMapPos(pt, focus, area):
+    return (pt[0] + focus[0] - area.centerx,
+            pt[1] + focus[1] - area.centery)
 
 class PregameMessage(elements.TextElement):
     def __init__(self, app, pos=None):
         if pos is None:
-            pos = Location(FullScreenAttachedPoint((0, -150), 'center'), 'center')
+            pos = Location(FullScreenAttachedPoint((0, -150), 'center'),
+                    'center')
         super(PregameMessage, self).__init__(
             app,
             '',
@@ -615,6 +602,16 @@ class GameViewer(framework.CompoundElement):
         self.toggleInterface()
         self.toggleLeaderBoard()
 
+    def getZoneAtPoint(self, pos):
+        '''
+        Returns the zone at the given screen position. This may be on the
+        minimap or the main view.
+        '''
+        zone = self.miniMap.getZoneAtPoint(pos)
+        if zone is None:
+            zone = self.viewManager.getZoneAtPoint(pos)
+        return zone
+
     def resizeIfNeeded(self):
         '''
         Checks whether the application has resized and adjusts accordingly.
@@ -638,7 +635,8 @@ class GameViewer(framework.CompoundElement):
         self.miniMap = MiniMap(self.app, 20, self.world, self.viewManager)
         xPos = -10
         yPos = self.miniMap.getRect().bottom + self.zoneBarHeight - 5
-        messagePos = Location(FullScreenAttachedPoint((xPos, yPos), 'topright'), 'topright')
+        messagePos = Location(FullScreenAttachedPoint((xPos, yPos),
+                'topright'), 'topright')
         self.pregameMessage = PregameMessage(self.app, messagePos)
         self.zoneBar = ZoneProgressBar(self.app, self.world, self)
         self.leaderboard = LeaderBoard(self.app, self.world, self)
@@ -707,8 +705,8 @@ class GameViewer(framework.CompoundElement):
         pygame.key.set_repeat(300, 30)
         self.chatBox.reset()
         self.chatBox.setPlayer(player)
-        self.chatBox.Show()
+        self.chatBox.show()
 
     def closeChat(self):
-        self.chatBox.Close()
+        self.chatBox.close()
 
