@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2010 Joshua D Bartlett
+# Copyright (C) 2006-2011 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,11 +15,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import logging
+
 import pygame
-from twisted.internet import reactor, task
 
 from trosnoth.utils.utils import timeNow
-from trosnoth.utils import logging
 from trosnoth.gui.framework import framework
 from trosnoth.gui.framework.hint import Hint
 import trosnoth.gui.framework.prompt as prompt
@@ -33,21 +33,26 @@ from trosnoth.data import startupMenu
 from trosnoth.gui.common import (Location, ScaledSize, ScaledArea,
         ScaledLocation, SizedImage)
 
-from trosnoth.trosnothgui.pregame.imageRadioButton import ImageRadioButton, RadioButtonGroup
+from trosnoth.trosnothgui.pregame.imageRadioButton import (ImageRadioButton,
+        RadioButtonGroup)
+from trosnoth.utils.twist import WeakCallLater, WeakLoopingCall
 
 from trosnoth.data import getPath
 
-from trosnoth.network.networkDefines import maxTeamNameLength
+log = logging.getLogger('serverSetubTab')
+
+MAX_TEAM_NAME_LENGTH = 10
 
 class ServerSetupTab(Tab):
-    def __init__(self, app, tabContainer, startupInterface):
+    def __init__(self, app, tabContainer):
         super(ServerSetupTab, self).__init__(app, 'Start a Game')
         self.tabContainer = tabContainer
-        self.toCreate = ServerDoesntExistMenu(app, tabContainer, startupInterface, self)
-        self.created = ServerAlreadyExistsMenu(app, tabContainer, startupInterface, self)
+        self.toCreate = ServerDoesntExistMenu(app, tabContainer, self)
+        self.created = ServerAlreadyExistsMenu(app, tabContainer, self)
         self.setAppropriateElements()
 
-        # Refresh the elements list every now and then in case server has shut down.
+        # Refresh the elements list every now and then in case server has shut
+        # down.
         self._lastUpdate = timeNow()
 
     def setAppropriateElements(self):
@@ -72,9 +77,8 @@ class ServerSetupTab(Tab):
         super(ServerSetupTab, self).draw(screen)
 
 class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
-    def __init__(self, app, tabContainer, startupInterface, parent):
+    def __init__(self, app, tabContainer, parent):
         super(ServerDoesntExistMenu, self).__init__(app)
-        self.startupInterface = startupInterface
         self.tabContainer = tabContainer
         self.parent = parent
 
@@ -87,136 +91,117 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
 
         self.radio = RadioButtonGroup(app)
 
-        imageSize = ScaledSize(200,120)
-        imageSmall = SizedImage(getPath(startupMenu, 'small.png'),
-                                imageSize, (0,0,0))
-        imageLong  = SizedImage(getPath(startupMenu, 'long.png'),
-                                imageSize, (0,0,0))
-        imageLarge = SizedImage(getPath(startupMenu, 'large.png'),
-                                imageSize, (0,0,0))
+        imageSize = ScaledSize(200, 120)
+        imageSmall = SizedImage(getPath(startupMenu, 'small.png'), imageSize,
+                (0, 0, 0))
+        imageLong  = SizedImage(getPath(startupMenu, 'long.png'), imageSize,
+                (0, 0, 0))
+        imageLarge = SizedImage(getPath(startupMenu, 'large.png'), imageSize,
+                (0, 0, 0))
 
         largeRadio = ImageRadioButton(app, 'Standard',
-                                      ScaledArea(85,370,200,150), imageLarge)
-        largeRadio.value = (3,2)
+                ScaledArea(85, 370, 200, 150), imageLarge)
+        largeRadio.value = (3, 2)
         self.radio.add(largeRadio)
 
-        smallRadio = ImageRadioButton(app, 'Small',
-                                      ScaledArea(305, 370,200,150), imageSmall)
-        smallRadio.value = (1,1)
+        smallRadio = ImageRadioButton(app, 'Small', ScaledArea(305,
+                370, 200, 150), imageSmall)
+        smallRadio.value = (1, 1)
         self.radio.add(smallRadio)
 
-        longRadio = ImageRadioButton(app, 'Wide',
-                                     ScaledArea(85,540,200,150), imageLong)
-        longRadio.value = (5,1)
+        longRadio = ImageRadioButton(app, 'Wide', ScaledArea(85, 540, 200, 150),
+                imageLong)
+        longRadio.value = (5, 1)
         self.radio.add(longRadio)
 
         self.customRadio = ImageRadioButton(app, 'Custom',
-                                            ScaledArea(305,540,200,150), None)
+                ScaledArea(305,540,200,150), None)
         self.radio.add(self.customRadio)
-       
-        self.customOne = prompt.InputBox(self.app,
-                            ScaledArea(390, 605, 40, 60, 'midright'),
-                            initValue = '2', maxLength = 1,
-                            font = self.app.screenManager.fonts.hugeMenuFont,
-                            validator = prompt.intValidator)
+
+        self.customOne = prompt.InputBox(self.app, ScaledArea(390, 605, 40, 60,
+                'midright'), initValue='2', maxLength=1,
+                font=self.app.screenManager.fonts.hugeMenuFont,
+                validator=prompt.intValidator)
         self.customOne.onClick.addListener(self.setFocus)
         self.customOne.onClick.addListener(self.selectCustomRadio)
         self.customOne.onTab.addListener(self.customTab)
         self.customOne.onEnter.addListener(self.startServer)
         self.customOne.onEdit.addListener(self.customUpdated)
 
-        self.customTwo = prompt.InputBox(self.app,
-                            ScaledArea(422, 605, 40, 60, 'midleft'),
-                            initValue = '1', maxLength = 1,
-                            font = self.app.screenManager.fonts.hugeMenuFont,
-                            validator = prompt.intValidator)
+        self.customTwo = prompt.InputBox(self.app, ScaledArea(422, 605, 40, 60,
+                'midleft'), initValue='1', maxLength=1,
+                font=self.app.screenManager.fonts.hugeMenuFont,
+                validator=prompt.intValidator)
         self.customTwo.onClick.addListener(self.setFocus)
         self.customTwo.onClick.addListener(self.selectCustomRadio)
         self.customTwo.onTab.addListener(self.customTab)
         self.customTwo.onEnter.addListener(self.startServer)
         self.customTwo.onEdit.addListener(self.customUpdated)
 
-        self.customRadio.value = (int(self.customOne.value), int(self.customTwo.value))
+        self.customRadio.value = (int(self.customOne.value),
+                int(self.customTwo.value))
 
-        self.custom = [TextElement(self.app, 'x',
-                                   self.app.screenManager.fonts.hugeMenuFont,
-                                   ScaledLocation(405, 605, 'center'),
-                                   self.app.theme.colours.black),
-                       self.customOne,
-                       self.customTwo];
+        self.custom = [
+            TextElement(self.app, 'x',
+                self.app.screenManager.fonts.hugeMenuFont, ScaledLocation(405,
+                605, 'center'), self.app.theme.colours.black),
+            self.customOne,
+            self.customTwo,
+        ]
 
         self.radio.selected(largeRadio)
         self.radio.onSelectionChanged.addListener(self.setSelectionNumber)
 
-
         colours = app.theme.colours
         self.text = [
-                     TextElement(self.app, 'Game Name:', font,
-                                 ScaledLocation(85, 220),
-                                 colours.headingColour),
-                     TextElement(self.app, 'Team Size:', font,
-                                 ScaledLocation(600, 220),
-                                 colours.headingColour),
-                     TextElement(self.app, 'players per side',
-                                 app.screenManager.fonts.smallNoteFont,
-                                 ScaledLocation(720, 295),
-                                 colours.headingColour),
-                     TextElement(self.app, 'Time Limit:', font,
-                                 ScaledLocation(600, 360),
-                                 colours.headingColour),
-                     TextElement(self.app, 'minutes',
-                                 app.screenManager.fonts.menuFont,
-                                 ScaledLocation(720, 435),
-                                 colours.headingColour),
-                     ]
+            TextElement(self.app, 'Game Name:', font, ScaledLocation(85, 220),
+                    colours.headingColour),
+            TextElement(self.app, 'Team Size:', font, ScaledLocation(600, 220),
+                    colours.headingColour),
+            TextElement(self.app, 'players per side',
+                    app.screenManager.fonts.smallNoteFont, ScaledLocation(720,
+                    295), colours.headingColour),
+            TextElement(self.app, 'Time Limit:', font, ScaledLocation(600, 360),
+                    colours.headingColour),
+            TextElement(self.app, 'minutes', app.screenManager.fonts.menuFont,
+                    ScaledLocation(720, 435), colours.headingColour),
+        ]
 
-        self.invalidInputText = TextElement(self.app, '', self.app.screenManager.fonts.ampleMenuFont,
-                                            ScaledLocation(50, 770, 'bottomleft'),
-                                            colours.invalidDataColour)
-        self.serverInput = prompt.InputBox(self.app, ScaledArea(85, 275, 420, 60),
-                                      initValue = '',
-                                      font = font)
+        self.invalidInputText = TextElement(self.app, '',
+                self.app.screenManager.fonts.ampleMenuFont, ScaledLocation(50,
+                770, 'bottomleft'), colours.invalidDataColour)
+        self.serverInput = prompt.InputBox(self.app, ScaledArea(85, 275, 420,
+                60), initValue='', font=font)
         self.serverInput.onClick.addListener(self.setFocus)
         self.serverInput.onTab.addListener(self.tabNext)
         self.serverInput.onEnter.addListener(self.startServer)
 
-        self.maxPlayersInput = prompt.InputBox(self.app, ScaledArea(600, 275, 100, 60),
-                                           initValue = '10',
-                                           font = font, maxLength = 3,
-                                           validator = prompt.intValidator)
+        self.maxPlayersInput = prompt.InputBox(self.app, ScaledArea(600, 275,
+                100, 60), initValue='10', font=font, maxLength=3,
+                validator=prompt.intValidator)
         self.maxPlayersInput.onClick.addListener(self.setFocus)
         self.maxPlayersInput.onTab.addListener(self.tabNext)
         self.maxPlayersInput.onEnter.addListener(self.startServer)
 
-        self.gameDurationInput = prompt.InputBox(self.app, ScaledArea(600, 415, 100, 60),
-                                           initValue = '45',
-                                           font = font, maxLength = 3,
-                                           validator = prompt.intValidator)
+        self.gameDurationInput = prompt.InputBox(self.app, ScaledArea(600, 415,
+                100, 60), initValue='45', font=font, maxLength=3,
+                validator=prompt.intValidator)
         self.gameDurationInput.onClick.addListener(self.setFocus)
         self.gameDurationInput.onTab.addListener(self.tabNext)
         self.gameDurationInput.onEnter.addListener(self.startServer)
 
         self.noLimitBox = CheckBox(self.app, ScaledLocation(830, 368),
-                                           text = 'No Limit',
-                                           font = app.screenManager.fonts.smallNoteFont,
-                                           colour = colours.secondMenuColour,
-                                           initValue = False,
-                                           style='circle')
-        self.noLimitBox.onValueChanged.addListener(lambda sender: self.enableGameDuration(not sender.value))
-
-        from trosnoth.utils.jsonImport import json
-        if json == None:
-            self.warnForRecording = True
-        else:
-            self.warnForRecording = False
-        del json
+                text='No Limit', font=app.screenManager.fonts.smallNoteFont,
+                colour=colours.secondMenuColour, initValue=False,
+                style='circle')
+        self.noLimitBox.onValueChanged.addListener(lambda sender:
+                self.enableGameDuration(not sender.value))
 
         self.invisibleGameBox = CheckBox(self.app, ScaledLocation(600, 520),
-                                           text = 'Invisible game',
-                                           font = app.screenManager.fonts.smallNoteFont,
-                                           colour = colours.secondMenuColour,
-                                           initValue = False,
-                                           style='circle')
+                text='Invisible game',
+                font=app.screenManager.fonts.smallNoteFont,
+                colour=colours.secondMenuColour, initValue=False,
+                style='circle')
 
         igHint = Hint(app, 'Others will need to know your IP address to '
                 'connect.', self.invisibleGameBox,
@@ -228,18 +213,18 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
                 colours.startButton, colours.white)
         self.startButton.onClick.addListener(self.startServer)
 
-        self.input = [self.serverInput, self.maxPlayersInput, self.gameDurationInput]
+        self.input = [self.serverInput, self.maxPlayersInput,
+                self.gameDurationInput]
         self.enableGameDuration(True)
 
-        self.elements = self.text + self.input + \
-                        [
-                         self.invisibleGameBox,
-                         self.noLimitBox,
-                         self.invalidInputText,
-                         self.startButton,
-                         self.radio,
-                         igHint
-                        ] + self.custom
+        self.elements = self.text + self.input + [
+            self.invisibleGameBox,
+            self.noLimitBox,
+            self.invalidInputText,
+            self.startButton,
+            self.radio,
+            igHint
+        ] + self.custom
         self.setFocus(self.serverInput)
         self.lastSelection = -1
         self.setSelectionNumber(0)
@@ -254,11 +239,14 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
         playerSizes = [10, 4, 6]
         timeLimits = [45, 10, 20]
         chosenNum = int(self.maxPlayersInput.getValue())
-        if (self.lastSelection == -1 or self.lastSelection == 3 or playerSizes[self.lastSelection] == chosenNum) and index != 3:
+        if (self.lastSelection == -1 or self.lastSelection == 3 or
+                playerSizes[self.lastSelection] == chosenNum) and index != 3:
             self.maxPlayersInput.setValue(str(playerSizes[index]))
         if not self.noLimitBox.value:
             chosenLimit = int(self.gameDurationInput.getValue())
-            if (self.lastSelection == -1 or self.lastSelection == 3 or timeLimits[self.lastSelection] == chosenLimit) and index != 3:
+            if ((self.lastSelection == -1 or self.lastSelection == 3 or
+                    timeLimits[self.lastSelection] == chosenLimit) and
+                    index != 3):
                 self.gameDurationInput.setValue(str(timeLimits[index]))
 
         if index != 3 and index != -1:
@@ -271,7 +259,8 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
 
     def setTabOrder(self):
         if self._enableGameDuration:
-            self.tabOrder = [self.serverInput, self.maxPlayersInput, self.gameDurationInput]
+            self.tabOrder = [self.serverInput, self.maxPlayersInput,
+                    self.gameDurationInput]
         else:
             self.tabOrder = [self.serverInput, self.maxPlayersInput]
 
@@ -281,7 +270,8 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
 
     def customUpdated(self, object):
         if self.customOne.value != '' and self.customTwo.value != '':
-            self.customRadio.value = (int(self.customOne.value), int(self.customTwo.value))
+            self.customRadio.value = (int(self.customOne.value),
+                    int(self.customTwo.value))
         else:
             self.customRadio.value = None
 
@@ -291,7 +281,8 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
         hadFocus = self.gameDurationInput.hasFocus
         super(ServerDoesntExistMenu, self).setFocus(object)
         # If the game duration box had and now does not have focus
-        if hadFocus and not self.gameDurationInput.hasFocus and self.gameDurationInput.value == '':
+        if (hadFocus and not self.gameDurationInput.hasFocus and
+                self.gameDurationInput.value == ''):
             self.enableGameDuration(False)
             self.noLimitBox.setValue(True)
 
@@ -341,7 +332,6 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
         5. Record Replay?
         6. Invisible game?
         '''
-        # TODO: move these to a central location for server and interface to read
         numPlayers = (2, 128)
 
         self.setBackColours()
@@ -353,17 +343,15 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
         if self.serverInput.value == '':
             if not invalid:
                 invalid = True
-                #self.incorrectInput('Please give this game a name')
             self.serverInput.setBackColour(colours.invalidDataColour)
         else:
             name = self.serverInput.value
 
-        if numPlayers[0] <= self.getInt(self.maxPlayersInput.value) <= numPlayers[1]:
+        if (numPlayers[0] <= self.getInt(self.maxPlayersInput.value) <=
+                numPlayers[1]):
             maxPlayers = self.getInt(self.maxPlayersInput.value)
         else:
             if not invalid:
-                #self.incorrectInput('Must have between %d and %d players per team' %
-                #                    (numPlayers[0], numPlayers[1]))
                 invalid = True
             self.maxPlayersInput.setBackColour(colours.invalidDataColour)
 
@@ -376,7 +364,6 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
                 self.gameDurationInput.setBackColour(colours.invalidDataColour)
                 if not invalid:
                     invalid = True
-                    #self.incorrectInput('Please set a duration for this game')
 
         radioChoice = self.radio.getSelectedValue()
         if radioChoice is None:
@@ -384,7 +371,6 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
                 invalid = True
                 self.customOne.setBackColour(colours.invalidDataColour)
                 self.customTwo.setBackColour(colours.invalidDataColour)
-                #self.incorrectInput('Please choose a map size')
 
         if invalid:
             return None
@@ -423,9 +409,8 @@ class ServerDoesntExistMenu(framework.TabFriendlyCompoundElement):
 
 
 class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
-    def __init__(self, app, tabContainer, startupInterface, parent):
+    def __init__(self, app, tabContainer, parent):
         super(ServerAlreadyExistsMenu, self).__init__(app)
-        self.startupInterface = startupInterface
         self.tabContainer = tabContainer
         self.parent = parent
 
@@ -436,7 +421,7 @@ class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
         self.inputsEdited = False
         self.resetCountdownDefault = 30
         self.resetCountdown = self.resetCountdownDefault
-        self.resetTimer = task.LoopingCall(self.resetCountdownFunction)
+        self.resetTimer = WeakLoopingCall(self, 'resetCountdownFunction')
 
         self.delayedCall = None
         self._lastStatusUpdate = timeNow()
@@ -445,78 +430,79 @@ class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
         colours = app.theme.colours
 
         # Static text
-        self.staticText = [TextElement(self.app, 'Game Status:', font,
-                                 ScaledLocation(70, 255),
-                                 colours.headingColour),
-                           TextElement(self.app, 'Team Names:', font,
-                                 ScaledLocation(70, 335),
-                                 colours.headingColour),
-                           TextElement(self.app, 'Game Mode:', font,
-                                 ScaledLocation(70, 415),
-                                 colours.headingColour)]
+        self.staticText = [
+            TextElement(self.app, 'Game Status:', font, ScaledLocation(70, 255),
+                    colours.headingColour),
+            TextElement(self.app, 'Team Names:', font, ScaledLocation(70, 335),
+                    colours.headingColour),
+            TextElement(self.app, 'Game Mode:', font, ScaledLocation(70, 415),
+                    colours.headingColour)]
 
         # Dynamic text
-        self.assistanceText = TextElement(self.app, '', font,
-                                            ScaledLocation(70, 490),
-                                            colours.invalidDataColour)
+        self.assistanceText = TextElement(self.app, '', font, ScaledLocation(70,
+                490), colours.invalidDataColour)
         self.gameStatusText = TextElement(self.app, 'Not yet started', font,
-                                          ScaledLocation(350, 255),
-                                          colours.inactive)
+                ScaledLocation(350, 255), colours.inactive)
 
         self.dynamicText = [self.assistanceText, self.gameStatusText]
 
         # Input boxes
-        self.blueTeamInput = prompt.InputBox(self.app, ScaledArea(350, 320, 270, 60),
-                                             initValue = self.blueTeamName,
-                                             font = font, colour = colours.blueTeamSetup,
-                                             maxLength = maxTeamNameLength)
+        self.blueTeamInput = prompt.InputBox(self.app, ScaledArea(350, 320, 270,
+                60), initValue=self.blueTeamName, font=font,
+                colour=colours.blueTeamSetup, maxLength=MAX_TEAM_NAME_LENGTH)
         self.blueTeamInput.onClick.addListener(self.setFocus)
         self.blueTeamInput.onEdit.addListener(lambda sender: self.inputEdit())
         self.blueTeamInput.onTab.addListener(self.tabNext)
-        self.blueTeamInput.onEnter.addListener(lambda sender: self.saveSettings())
+        self.blueTeamInput.onEnter.addListener(lambda sender:
+                self.saveSettings())
 
-        self.redTeamInput = prompt.InputBox(self.app, ScaledArea(655, 320, 270, 60),
-                                            initValue = self.redTeamName,
-                                            font = font, colour = colours.redTeamSetup,
-                                            maxLength = maxTeamNameLength)
+        self.redTeamInput = prompt.InputBox(self.app, ScaledArea(655, 320, 270,
+                60), initValue=self.redTeamName, font=font,
+                colour=colours.redTeamSetup, maxLength=MAX_TEAM_NAME_LENGTH)
         self.redTeamInput.onClick.addListener(self.setFocus)
         self.redTeamInput.onEdit.addListener(lambda sender: self.inputEdit())
         self.redTeamInput.onTab.addListener(self.tabNext)
-        self.redTeamInput.onEnter.addListener(lambda sender: self.saveSettings())
+        self.redTeamInput.onEnter.addListener(lambda sender:
+                self.saveSettings())
 
-        self.gameModeInput = prompt.InputBox(self.app, ScaledArea(350, 400, 575, 60),
-                                             initValue = self.gameMode,
-                                             font = font, colour = colours.white,
-                                             maxLength = 20)
+        self.gameModeInput = prompt.InputBox(self.app, ScaledArea(350, 400, 575,
+                60), initValue=self.gameMode, font=font, colour=colours.white,
+                maxLength=20)
         self.gameModeInput.onClick.addListener(self.setFocus)
         self.gameModeInput.onEdit.addListener(lambda sender: self.inputEdit())
         self.gameModeInput.onTab.addListener(self.tabNext)
-        self.gameModeInput.onEnter.addListener(lambda sender: self.saveSettings())
+        self.gameModeInput.onEnter.addListener(lambda sender:
+                self.saveSettings())
 
-        self.input = self.tabOrder = [self.blueTeamInput, self.redTeamInput, self.gameModeInput]
+        self.input = self.tabOrder = [self.blueTeamInput, self.redTeamInput,
+                self.gameModeInput]
 
         # Text buttons
-        self.shutdownButton = TextButton(self.app, ScaledLocation(410, 645, 'center'),
-                                         'Shut Down Server',
-                                         app.screenManager.fonts.hugeMenuFont,
-                                         colours.noGamesColour, colours.white)
-        self.shutdownButton.onClick.addListener(lambda sender: self.shutdownServer())
+        self.shutdownButton = TextButton(self.app, ScaledLocation(410, 645,
+                'center'), 'Shut Down Server',
+                app.screenManager.fonts.hugeMenuFont, colours.noGamesColour,
+                colours.white)
+        self.shutdownButton.onClick.addListener(lambda sender:
+                self.shutdownServer())
         self.shutdownWarning = False
 
-        self.startGameButton = TextButton(self.app, ScaledLocation(925, 255, 'topright'),
-                                          'force begin', font,
-                                          colours.secondMenuColour, colours.white)
-        self.startGameButton.onClick.addListener(lambda sender: self.startGame())
+        self.startGameButton = TextButton(self.app, ScaledLocation(925, 255,
+                'topright'), 'force begin', font, colours.secondMenuColour,
+                colours.white)
+        self.startGameButton.onClick.addListener(lambda sender:
+                self.startGame())
 
-        self.saveButton = TextButton(self.app, ScaledLocation(925, 490, 'topright'),
-                                     'save settings', font,
-                                     colours.secondMenuColour, colours.white)
+        self.saveButton = TextButton(self.app, ScaledLocation(925, 490,
+                'topright'), 'save settings', font, colours.secondMenuColour,
+                colours.white)
         self.saveButton.onClick.addListener(lambda sender: self.saveSettings())
 
-        self.buttons = [self.shutdownButton, self.startGameButton, self.saveButton]
+        self.buttons = [self.shutdownButton, self.startGameButton,
+                self.saveButton]
 
         # By your powers combined, I am Captain Planet!
-        self.elements = self.staticText + self.dynamicText + self.input + self.buttons
+        self.elements = (self.staticText + self.dynamicText + self.input +
+                self.buttons)
 
         self.updateStatus()
 
@@ -561,21 +547,21 @@ class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
     def shutdownServer(self):
         self.shutdownConfirmationBox = ShutdownDialog(self.app)
         self.shutdownConfirmationBox.onClose.addListener(self._shutdownDlgClose)
-        self.shutdownConfirmationBox.Show()
+        self.shutdownConfirmationBox.show()
 
     def _shutdownDlgClose(self):
         if self.shutdownConfirmationBox.result == DialogResult.OK:
             if self.app.server is not None:
                 self.app.server.shutdown()
 
-    # The following three functions are all related: if a user edits the team names or gamde mode
-    # but doesn't save them, they will get a certain amount of time before the inputs are reset to
-    # those obtained from the server.
+    # The following three functions are all related: if a user edits the team
+    # names or gamde mode but doesn't save them, they will get a certain amount
+    # of time before the inputs are reset to those obtained from the server.
 
     def inputEdit(self):
-        if self.blueTeamInput.getValue().strip() != self.blueTeamName or \
-            self.redTeamInput.getValue().strip() != self.redTeamName or \
-            self.gameModeInput.getValue().strip() != self.gameMode:
+        if (self.blueTeamInput.getValue().strip() != self.blueTeamName or
+                self.redTeamInput.getValue().strip() != self.redTeamName or
+                self.gameModeInput.getValue().strip() != self.gameMode):
             if not self.inputsEdited:
                 self.inputsEdited = True
                 self.resetTimer.start(1.0, False)
@@ -585,8 +571,8 @@ class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
     def resetCountdownFunction(self):
         try:
             self._resetCountdownFunction()
-        except:
-            logging.writeException()
+        except Exception, e:
+            log.exception(str(e))
 
     def _resetCountdownFunction(self):
         self.resetCountdown -= 1
@@ -621,7 +607,7 @@ class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
         self.gameModeInput.setValue(self.gameMode)
 
     def delayedErase(self, element, time = 3):
-        self.delayedCall = reactor.callLater(time, self.clearText, element)
+        self.delayedCall = WeakCallLater(time, self, 'clearText', element)
 
     def clearText(self, element):
         element.setText('')
@@ -693,10 +679,12 @@ class ServerAlreadyExistsMenu(framework.TabFriendlyCompoundElement):
         super(ServerAlreadyExistsMenu, self).draw(screen)
 
 class ShutdownDialog(DialogBox):
-    '''Defines the elements and layout thereof of the server shutdown confirmation dialog box.'''
+    '''Defines the elements and layout thereof of the server shutdown
+    confirmation dialog box.'''
 
     def __init__(self, app):
-        super(ShutdownDialog, self).__init__(app, ScaledSize(450, 340), 'Server Shutdown')
+        super(ShutdownDialog, self).__init__(app, ScaledSize(450, 340),
+                'Server Shutdown')
         colours = app.theme.colours
 
         # Warning message
@@ -743,9 +731,9 @@ class ShutdownDialog(DialogBox):
 
     def ok(self):
         self.result = DialogResult.OK
-        self.Close()
+        self.close()
 
     def cancel(self):
         self.result = DialogResult.Cancel
-        self.Close()
+        self.close()
 
