@@ -268,12 +268,8 @@ def playNow(state, request):
 
 @pages.addPage('/play')
 def play(state, request):
-    hostName = request.getRequestHostname()
-    port = request.getHost().port
-    if port == 80:
-        homeAddress = 'http://%s/' % (hostName,)
-    else:
-        homeAddress = 'http://%s:%s/' % (hostName, port)
+    hostName = state.getHostName()
+    homeAddress = state.getHomeAddress()
     return pageTemplate.apply(
         title=cgi.escape(state.getName()),
         contents='''
@@ -584,6 +580,32 @@ class WebServer(ServerState):
     def getName(self):
         return self.authFactory.settings.serverName
 
+    def getHostName(self, req):
+        '''
+        Returns the host name of this server (for purpsose of connecting to
+        Trosnoth games). This is taken from the settings file or (if no setting
+        is given) from the request itself.
+        '''
+        hostName = self.authFactory.settings.hostName
+        if not hostName:
+            hostName = req.getRequestHostname()
+        return hostName
+
+    def getHomeAddress(self, req):
+        '''
+        Returns the home address of this server site, either from the settings
+        file or (if no setting is given), from the request itself.
+        '''
+        homeAddress = self.authFactory.settings.serverName
+        if not homeAddress:
+            hostName = req.getRequestHostname()
+            port = req.getHost().port
+            if port == 80:
+                homeAddress = 'http://%s/' % (hostName,)
+            else:
+                homeAddress = 'http://%s:%s/' % (hostName, port)
+        return homeAddress
+
     def getPlayer(self, username):
         authMan = self.authFactory.authManager
         if authMan.checkUsername(username):
